(function () {

/* Imports */
var Meteor = Package.meteor.Meteor;
var global = Package.meteor.global;
var meteorEnv = Package.meteor.meteorEnv;
var ECMAScript = Package.ecmascript.ECMAScript;
var _ = Package.underscore._;
var AppConfig = Package['application-configuration'].AppConfig;
var meteorInstall = Package.modules.meteorInstall;
var Buffer = Package.modules.Buffer;
var process = Package.modules.process;
var Symbol = Package['ecmascript-runtime'].Symbol;
var Map = Package['ecmascript-runtime'].Map;
var Set = Package['ecmascript-runtime'].Set;
var meteorBabelHelpers = Package['babel-runtime'].meteorBabelHelpers;
var Promise = Package.promise.Promise;

/* Package-scope variables */
var SandstormEmail;

var require = meteorInstall({"node_modules":{"meteor":{"sandstorm-email":{"email.js":function(require){

/////////////////////////////////////////////////////////////////////////////////////////////////////////////
//                                                                                                         //
// packages/sandstorm-email/email.js                                                                       //
//                                                                                                         //
/////////////////////////////////////////////////////////////////////////////////////////////////////////////
                                                                                                           //
var Future = Npm.require("fibers/future");                                                                 // 1
var urlModule = Npm.require("url");                                                                        // 2
var MailComposer = Npm.require("mailcomposer").MailComposer;                                               // 3
                                                                                                           //
SandstormEmail = {};                                                                                       // 5
                                                                                                           //
var getSmtpConfig = function getSmtpConfig() {                                                             // 7
  var config = Settings.findOne({ _id: "smtpConfig" });                                                    // 8
  return config && config.value;                                                                           // 9
};                                                                                                         // 10
                                                                                                           //
var makePool = function makePool(mailConfig) {                                                             // 12
  var simplesmtp = Npm.require("simplesmtp");                                                              // 13
  var auth = false;                                                                                        // 14
  if (mailConfig.auth && (mailConfig.auth.user || mailConfig.auth.pass)) {                                 // 15
    auth = mailConfig.auth;                                                                                // 16
  }                                                                                                        // 17
                                                                                                           //
  var pool = simplesmtp.createClientPool(mailConfig.port, mailConfig.hostname, { secureConnection: mailConfig.port === 465,
    // XXX allow maxConnections to be configured?                                                          //
    auth: auth });                                                                                         // 24
                                                                                                           //
  pool._futureWrappedSendMail = _.bind(Future.wrap(pool.sendMail), pool);                                  // 26
  return pool;                                                                                             // 27
};                                                                                                         // 28
                                                                                                           //
// We construct the SMTP pool at the first call to Email.send, so that                                     //
// other code like migrations can modify the SMTP configuration.                                           //
var pool = void 0;                                                                                         // 32
var configured = false;                                                                                    // 33
                                                                                                           //
Meteor.startup(function () {                                                                               // 35
  Settings.find({ _id: "smtpConfig" }).observeChanges({                                                    // 36
    removed: function removed() {                                                                          // 37
      configured = false;                                                                                  // 38
    },                                                                                                     // 39
                                                                                                           //
    changed: function changed() {                                                                          // 41
      configured = false;                                                                                  // 42
    },                                                                                                     // 43
                                                                                                           //
    added: function added() {                                                                              // 45
      configured = false;                                                                                  // 46
    }                                                                                                      // 47
  });                                                                                                      // 36
});                                                                                                        // 49
                                                                                                           //
var getPool = function getPool(smtpConfig) {                                                               // 51
  if (smtpConfig) {                                                                                        // 52
    return makePool(smtpConfig);                                                                           // 53
  } else if (!configured) {                                                                                // 54
    configured = true;                                                                                     // 55
    var config = getSmtpConfig();                                                                          // 56
    if (config) {                                                                                          // 57
      pool = makePool(config);                                                                             // 58
    }                                                                                                      // 59
  }                                                                                                        // 60
                                                                                                           //
  return pool;                                                                                             // 62
};                                                                                                         // 63
                                                                                                           //
var nextDevmodeMailId = 0;                                                                                 // 65
var outputStream = process.stdout;                                                                         // 66
                                                                                                           //
var devModeSend = function devModeSend(mc) {                                                               // 68
  // This seems to be dead code.                                                                           //
  var devmodeMailId = nextDevmodeMailId++;                                                                 // 70
                                                                                                           //
  var stream = outputStream;                                                                               // 72
                                                                                                           //
  // This approach does not prevent other writers to stdout from interleaving.                             //
  stream.write("====== BEGIN MAIL #" + devmodeMailId + " ======\n");                                       // 75
  stream.write("(Mail not sent; to enable sending, set the MAIL_URL " + "environment variable.)\n");       // 76
  mc.streamMessage();                                                                                      // 78
  mc.pipe(stream, { end: false });                                                                         // 79
  var future = new Future();                                                                               // 80
  mc.on("end", function () {                                                                               // 81
    stream.write("====== END MAIL #" + devmodeMailId + " ======\n");                                       // 82
    future["return"]();                                                                                    // 83
  });                                                                                                      // 84
                                                                                                           //
  future.wait();                                                                                           // 86
};                                                                                                         // 87
                                                                                                           //
var smtpSend = function smtpSend(pool, mc) {                                                               // 89
  pool._futureWrappedSendMail(mc).wait();                                                                  // 90
};                                                                                                         // 91
                                                                                                           //
// Old comment below                                                                                       //
/**                                                                                                        //
 * Send an email.                                                                                          //
 *                                                                                                         //
 * Connects to the mail server configured via the MAIL_URL environment                                     //
 * variable. If unset, prints formatted message to stdout. The "from" option                               //
 * is required, and at least one of "to", "cc", and "bcc" must be provided;                                //
 * all other options are optional.                                                                         //
 *                                                                                                         //
 * @param options                                                                                          //
 * @param options.from {String} RFC5322 "From:" address                                                    //
 * @param options.to {String|String[]} RFC5322 "To:" address[es]                                           //
 * @param options.cc {String|String[]} RFC5322 "Cc:" address[es]                                           //
 * @param options.bcc {String|String[]} RFC5322 "Bcc:" address[es]                                         //
 * @param options.replyTo {String|String[]} RFC5322 "Reply-To:" address[es]                                //
 * @param options.subject {String} RFC5322 "Subject:" line                                                 //
 * @param options.text {String} RFC5322 mail body (plain text)                                             //
 * @param options.html {String} RFC5322 mail body (HTML)                                                   //
 * @param options.headers {Object} custom RFC5322 headers (dictionary)                                     //
 */                                                                                                        //
                                                                                                           //
// New API doc comment below                                                                               //
/**                                                                                                        //
 * @summary Send an email. Throws an `Error` on failure to contact mail server                             //
 * or if mail server returns an error. All fields should match                                             //
 * [RFC5322](http://tools.ietf.org/html/rfc5322) specification.                                            //
 * @locus Server                                                                                           //
 * @param {Object} options                                                                                 //
 * @param {String} options.from "From:" address (required)                                                 //
 * @param {String|String[]} options.to,cc,bcc,replyTo                                                      //
 *   "To:", "Cc:", "Bcc:", and "Reply-To:" addresses                                                       //
 * @param {String} [options.subject]  "Subject:" line                                                      //
 * @param {String} [options.text|html] Mail body (in plain text or HTML)                                   //
 * @param {Object} [options.headers] Dictionary of custom headers                                          //
 * @param {Object} [options.smtpConfig] SMTP server to use. Otherwise defaults to configured one.          //
 * @param {String} [options.smtpConfig.hostname] SMTP server hostname.                                     //
 * @param {Number} [options.smtpConfig.port] SMTP server port.                                             //
 * @param {Object} [options.smtpConfig.auth] SMTP server authentication tokens.  Optional.                 //
 * @param {String} [options.smtpConfig.auth.user] Username of user to log in to SMTP server as.  Optional.
 * @param {String} [options.smtpConfig.auth.pass] Password of user to log in to SMTP server as.  Optional.
 * @param {Object} [options.attachments] Attachments. See:                                                 //
 *   https://github.com/nodemailer/mailcomposer/tree/v0.1.15#add-attachments                               //
 * @param {String} [options.envelopeFrom] Envelope sender.                                                 //
 */                                                                                                        //
SandstormEmail.send = function (options) {                                                                 // 137
  var mc = new MailComposer();                                                                             // 138
                                                                                                           //
  // setup message data                                                                                    //
  mc.setMessageOption({                                                                                    // 141
    from: options.from,                                                                                    // 142
    to: options.to,                                                                                        // 143
    cc: options.cc,                                                                                        // 144
    bcc: options.bcc,                                                                                      // 145
    replyTo: options.replyTo,                                                                              // 146
    subject: options.subject,                                                                              // 147
    text: options.text,                                                                                    // 148
    html: options.html                                                                                     // 149
  });                                                                                                      // 141
                                                                                                           //
  if (options.envelopeFrom) {                                                                              // 152
    var envelope = mc.getEnvelope();                                                                       // 153
    envelope.from = options.envelopeFrom;                                                                  // 154
    mc.setMessageOption({                                                                                  // 155
      envelope: envelope                                                                                   // 156
    });                                                                                                    // 155
  }                                                                                                        // 158
                                                                                                           //
  _.each(options.headers, function (value, name) {                                                         // 160
    mc.addHeader(name, value);                                                                             // 161
  });                                                                                                      // 162
                                                                                                           //
  _.each(options.attachments, function (value) {                                                           // 164
    mc.addAttachment(value);                                                                               // 165
  });                                                                                                      // 166
                                                                                                           //
  SandstormEmail.rawSend(mc, options.smtpConfig);                                                          // 168
};                                                                                                         // 169
                                                                                                           //
/**                                                                                                        //
 * @summary Sends a raw email with a MailComposer object.                                                  //
 * Throws an `Error` on failure to contact mail server                                                     //
 * or if mail server returns an error. All fields should match                                             //
 * [RFC5322](http://tools.ietf.org/html/rfc5322) specification.                                            //
 * @locus Server                                                                                           //
 * @param {Object} mc A MailCompser object that you wish to send                                           //
 * @param {String} smtpUrl SMTP server to use. If falsey, defaults to configured one.                      //
*/                                                                                                         //
SandstormEmail.rawSend = function (mc, smtpConfig) {                                                       // 180
  // SimpleSmtp does not add leading dots, so we need to.                                                  //
  // See http://tools.ietf.org/html/rfc5321#section-4.5.2                                                  //
  mc._message.body = mc._message.body.replace(/(^|\n)\./g, "$1..");                                        // 183
                                                                                                           //
  var pool = getPool(smtpConfig);                                                                          // 185
  if (pool) {                                                                                              // 186
    smtpSend(pool, mc);                                                                                    // 187
  } else {                                                                                                 // 188
    throw new Error("SMTP pool is misconfigured.");                                                        // 189
  }                                                                                                        // 190
};                                                                                                         // 191
/////////////////////////////////////////////////////////////////////////////////////////////////////////////

}}}}},{"extensions":[".js",".json"]});
require("./node_modules/meteor/sandstorm-email/email.js");

/* Exports */
if (typeof Package === 'undefined') Package = {};
(function (pkg, symbols) {
  for (var s in symbols)
    (s in pkg) || (pkg[s] = symbols[s]);
})(Package['sandstorm-email'] = {}, {
  SandstormEmail: SandstormEmail
});

})();

//# sourceMappingURL=sandstorm-email.js.map
